Crate kcr_jetstream_nats_io

Crate kcr_jetstream_nats_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the jetstream.nats.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

jetstream.nats.io/v1beta1

  • Consumer
  • Stream
  • StreamTemplate

jetstream.nats.io/v1beta2

  • Account
  • Consumer
  • KeyValue
  • ObjectStore
  • Stream

Modules

v1beta1
v1beta2