This crate contains kube-rs compatible bindings for Kubernetes custom resources for the jetstream.nats.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
jetstream.nats.io/v1beta1
ConsumerStreamStreamTemplate
jetstream.nats.io/v1beta2
AccountConsumerKeyValueObjectStoreStream